# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`gitlabinstall`](#gitlabinstall): GitLab installation
* [`gitlabinstall::external_registry`](#gitlabinstallexternal_registry): External registry integration into GitLab
* [`gitlabinstall::gitlab`](#gitlabinstallgitlab): GitLab installation management
* [`gitlabinstall::ldap`](#gitlabinstallldap): Setup LDAP settings for GitLab instance
* [`gitlabinstall::nginx`](#gitlabinstallnginx): A short summary of the purpose of this class
* [`gitlabinstall::params`](#gitlabinstallparams): Basic module settings
* [`gitlabinstall::postgres`](#gitlabinstallpostgres): Install postgres database and pg_trgm extension
* [`gitlabinstall::ssl`](#gitlabinstallssl): A short summary of the purpose of this class

### Resource types

* [`registry_token`](#registry_token): Registry authentication JWT token

## Classes

### `gitlabinstall`

GitLab installation

#### Examples

##### 

```puppet
include gitlabinstall
```

#### Parameters

The following parameters are available in the `gitlabinstall` class.

##### `gitlab_package_ensure`

Data type: `String`

RPM package version. For example, 13.3.2-ce.0.el7 (see https://packages.gitlab.com/gitlab/gitlab-ce)

Default value: `'13.0.10-ce.0.el7'`

##### `external_url`

Data type: `Stdlib::HTTPUrl`

Configuring the external URL for GitLab
see [Configuring the external URL for GitLab](https://docs.gitlab.com/omnibus/settings/configuration.html#configuring-the-external-url-for-gitlab)

Default value: `'http://localhost'`

##### `database_password`

Data type: `Optional[String]`

PostgreSQL database password

Default value: ``undef``

##### `manage_cert_data`

Data type: `Boolean`

Whether provided certificate and key should be installed on server or not

Default value: ``true``

##### `cert_identity`

Data type: `Optional[String]`

Certificate name to use in order to lookup certificate data in Puppet Hiera

Default value: ``undef``

##### `external_postgresql_service`

Data type: `Boolean`

Using a non-packaged PostgreSQL database management server
see [Using a non-packaged PostgreSQL database management server](https://docs.gitlab.com/omnibus/settings/database.html#using-a-non-packaged-postgresql-database-management-server)

Default value: ``true``

##### `manage_postgresql_core`

Data type: `Boolean`

Whether to manage PostgreSQL core or not (installation, initialization,
service start)

Default value: ``true``

##### `non_bundled_web_server`

Data type: `Boolean`

Whether to use bundled into GitLab Nginx service or not

Default value: ``true``

##### `manage_nginx_core`

Data type: `Boolean`

Whether to manage core settings for Nginx or not (installation, nginx.conf
setup, service setup)

Default value: ``true``

##### `external_registry_service`

Data type: `Boolean`

Whether to integrate external Container registry into GitLab or not

Default value: ``false``

##### `registry_host`

Data type: `Optional[Stdlib::Fqdn]`

Registry endpoint without the scheme, the address that gets shown to the end user.

Default value: ``undef``

##### `registry_port`

Data type: `Integer`

Registry endpoint port, visible to the end user

Default value: `443`

##### `registry_api_url`

Data type: `Stdlib::HTTPUrl`

Registry API URL Gitlab should connect to

Default value: `'http://localhost:5000'`

##### `ldap_enabled`

Data type: `Boolean`

Whether to enable LDAP settings or not

Default value: ``false``

##### `ldap_base`

Data type: `Optional[String]`

LDAP base where we can search for users.

Default value: ``undef``

##### `ldap_password`

Data type: `Optional[String]`

The password of the LDAP bind user.

Default value: ``undef``

##### `ldap_host`

Data type: `Optional[String]`

IP address or domain name of your LDAP server.

Default value: ``undef``

##### `database_host`

Data type: `Variant[Stdlib::Fqdn, Stdlib::IP::Address]`



Default value: `'localhost'`

##### `monitoring_whitelist`

Data type: `Array[Stdlib::IP::Address]`



Default value: `[]`

### `gitlabinstall::external_registry`

External registry integration into GitLab

#### Examples

##### 

```puppet
include gitlabinstall::external_registry
```

#### Parameters

The following parameters are available in the `gitlabinstall::external_registry` class.

##### `registry_host`

Data type: `Stdlib::Fqdn`

Registry endpoint without the scheme, the address that gets shown to the end user.
it is gitlab_rails['registry_host'] setting in /etc/gitlab/gitlab.rb

Default value: `$gitlabinstall::registry_host`

##### `registry_api_url`

Data type: `Stdlib::HTTPUrl`

This is the Registry URL used internally that users do not need to interact with
it is gitlab_rails['registry_api_url'] setting in /etc/gitlab/gitlab.rb

Default value: `$gitlabinstall::registry_api_url`

##### `registry_port`

Data type: `Integer`

Registry endpoint port, visible to the end user
it is gitlab_rails['registry_port'] setting in /etc/gitlab/gitlab.rb

Default value: `$gitlabinstall::registry_port`

##### `registry_internal_key`

Data type: `Optional[String]`

Contents of the key that GitLab uses to sign the tokens.
It is registry['internal_key'] setting in /etc/gitlab/gitlab.rb
A certificate-key pair is required for GitLab and the external container
registry to communicate securely. You will need to create a certificate-key
pair, configuring the external container registry with the public certificate
and configuring GitLab with the private key

Default value: ``undef``

##### `registry_key_path`

Path to the key that matches the certificate on the Registry side.
It is gitlab_rails['registry_key_path'] setting in /etc/gitlab/gitlab.rb
Custom file for Omnibus GitLab to write the contents of
registry['internal_key'] to. The file specified at `registry_key_path` gets
populated with the content specified by `internal_key`, each time reconfigure
is executed. If no file is specified, Omnibus GitLab will default it to
`/var/opt/gitlab/gitlab-rails/etc/gitlab-registry.key` and will populate it.

##### `registry_internal_certificate`

Data type: `Optional[String]`

Contents of the certificate that GitLab uses to sign the tokens. This
parameter allows to setup custom certificate into file system path
(`registry_cert_path`) or export to Puppet DB. It will not influence on
GitLab configuration (there is no support to embedded registry configuration
in this moodule)

Default value: ``undef``

##### `registry_cert_path`

Data type: `Optional[Stdlib::Unixpath]`

This is the path where `registry_internal_certificate` contents will be
written to disk.
default certificate location is /var/opt/gitlab/registry/gitlab-registry.crt

Default value: ``undef``

##### `registry_cert_export`

Data type: `Boolean`

Whether to write certificate content intoo local file system or export it to
Puppet DB

Default value: ``true``

##### `token_username`

Data type: `String`

Username to use for default JWT auth token (as subject field). This token
will be generated and stored into file `/etc/docker/registry/token.json`
and available through custom fact `gitlab_auth_token`

Default value: `'registry-bot'`

##### `token_expire_time`

Data type: `Optional[String]`

Expiration time for default JWT token. Could be unix timestamp or string
representation of a time (which could be parsed by ruby function Time.parse)
Default expiration time is 3600 seconds after current time

Default value: ``undef``

##### `token_expire_threshold`

Data type: `Optional[Integer]`

Threshold for expiration time in seconds. If expiration time is less then
current time plus threshold than Puppet will generate new auth token.
Default threshold is 600 seconds

Default value: ``undef``

### `gitlabinstall::gitlab`

GitLab installation management

#### Examples

##### 

```puppet
include gitlabinstall::gitlab
```

#### Parameters

The following parameters are available in the `gitlabinstall::gitlab` class.

##### `gitlab_package_ensure`

Data type: `String`

RPM package version. For example, 13.3.2-ce.0.el7 (see https://packages.gitlab.com/gitlab/gitlab-ce)

Default value: `$gitlabinstall::gitlab_package_ensure`

##### `log_dir`

Data type: `String`

Log directory to manage

Default value: `'/var/log/gitlab'`

##### `external_postgresql_service`

Data type: `Boolean`

Using a non-packaged PostgreSQL database management server
see [Using a non-packaged PostgreSQL database management server](https://docs.gitlab.com/omnibus/settings/database.html#using-a-non-packaged-postgresql-database-management-server)

Default value: `$gitlabinstall::external_postgresql_service`

##### `packages_enabled`

Data type: `Boolean`

Enabling the Packages feature
see [GitLab Package Registry administration](https://docs.gitlab.com/ee/administration/packages/)

Default value: ``true``

##### `packages_storage_path`

Data type: `Optional[Stdlib::Unixpath]`

Local storage path for packages for Omnibus GitLab installation

Default value: `$gitlabinstall::params::packages_storage_path`

##### `ssl_cert`

Data type: `Optional[String]`

Content of x509 certificate to use for GitLab TLS setup

Default value: ``undef``

##### `ssl_key`

Data type: `Optional[String]`

Content of RSA private key to use for GitLab TLS setup

Default value: ``undef``

##### `repo_sslverify`

Data type: `Optional[Integer[0,1]]`

Set `sslverify` flag for Omnibus GitLab Yum repository

Default value: ``undef``

##### `monitoring_whitelist`

Data type: `Array[Stdlib::IP::Address]`

GitLab provides liveness and readiness probes to indicate service health.
To access monitoring resources, the requesting client IP needs to be
included in a whitelist.
See https://docs.gitlab.com/ee/administration/monitoring/ip_whitelist.html

Default value: `$gitlabinstall::monitoring_whitelist`

##### `database_password`

Data type: `String[8]`



Default value: `$gitlabinstall::database_password`

##### `manage_postgresql_core`

Data type: `Boolean`



Default value: `$gitlabinstall::manage_postgresql_core`

##### `database_host`

Data type: `String`



Default value: `$gitlabinstall::database_host`

##### `database_port`

Data type: `Variant[Integer, Pattern[/^[0-9]+$/]]`



Default value: `$gitlabinstall::params::database_port`

##### `database_username`

Data type: `String`



Default value: `$gitlabinstall::params::database_username`

##### `database_name`

Data type: `String`



Default value: `$gitlabinstall::params::database_name`

##### `non_bundled_web_server`

Data type: `Boolean`



Default value: `$gitlabinstall::non_bundled_web_server`

##### `manage_nginx_core`

Data type: `Boolean`



Default value: ``true``

##### `manage_cert_data`

Data type: `Boolean`



Default value: ``true``

##### `cert_identity`

Data type: `Optional[String]`



Default value: ``undef``

##### `gitlab_rails_host`

Data type: `String`



Default value: `'localhost'`

##### `gitlab_rails_port`

Data type: `Integer`



Default value: `8080`

##### `monitoring`

Data type: `Boolean`



Default value: ``false``

##### `external_registry_service`

Data type: `Boolean`



Default value: `$gitlabinstall::external_registry_service`

##### `mnt_distro`

Data type: `Optional[Stdlib::Unixpath]`



Default value: ``undef``

##### `mnt_distro_fstype`

Data type: `String`



Default value: `'ext4'`

##### `mnt_data`

Data type: `Optional[Stdlib::Unixpath]`



Default value: ``undef``

##### `mnt_data_fstype`

Data type: `String`



Default value: `'ext4'`

##### `ldap_enabled`

Data type: `Boolean`



Default value: `$gitlabinstall::ldap_enabled`

### `gitlabinstall::ldap`

Setup LDAP settings for GitLab instance
see https://docs.gitlab.com/ee/administration/auth/ldap/

#### Examples

##### 

```puppet
include gitlabinstall::ldap
```

#### Parameters

The following parameters are available in the `gitlabinstall::ldap` class.

##### `base`

Data type: `String`

Base where we can search for users.

Default value: `$gitlabinstall::ldap_base`

##### `prevent_ldap_sign_in`

Data type: `Boolean`

When using another system such as SAML for authentication it can be
desirable to disable LDAP for authentication. In particular LDAP can be a
useful technology for synchronizing group membership, while being a
security risk for sign in due to the way passwords are handled. Additionally
it can allow users to bypass 2FA policies.

Default value: ``false``

##### `active_directory`

Data type: `Boolean`

This setting specifies if LDAP server is Active Directory LDAP server. For
non-AD servers it skips the AD specific queries. If your LDAP server is not
AD, set this to false.

Default value: ``false``

##### `allow_username_or_email_login`

Data type: `Boolean`

If enabled, GitLab will ignore everything after the first @ in the LDAP
username submitted by the user on sign-in. If you are using uid:
`userPrincipalName` on ActiveDirectory you need to disable this setting,
because the userPrincipalName contains an @.

Default value: ``false``

##### `bind_dn`

Data type: `Optional[String]`

The full DN of the user you will bind with.

Default value: ``undef``

##### `block_auto_created_users`

Data type: `Boolean`

To maintain tight control over the number of active users on your GitLab
installation, enable this setting to keep new users blocked until they have
been cleared by the admin.

Default value: ``true``

##### `group_base`

Data type: `Optional[String]`

Base used to search for groups.

Default value: ``undef``

##### `host`

Data type: `Variant[Stdlib::Fqdn, Stdlib::IP::Address]`

IP address or domain name of your LDAP server.

Default value: `$gitlabinstall::ldap_host`

##### `label`

Data type: `String`

A human-friendly name for your LDAP server. It will be displayed on your
sign-in page.

Default value: `'LDAP'`

##### `encryption`

Data type: `Enum['simple_tls', 'start_tls', 'plain']`

Encryption method. The `method` key is deprecated in favor of `encryption`.
The `encryption` value `simple_tls` corresponds to 'Simple TLS' in the LDAP
library. `start_tls` corresponds to StartTLS, not to be confused with
regular TLS. Normally, if you specify `simple_tls` it will be on port 636,
while `start_tls` (StartTLS) would be on port 389. `plain` also operates on
port 389. Removed values: `tls` was replaced with `start_tls` and `ssl` was
replaced with `simple_tls`.

Default value: `'simple_tls'`

##### `password`

Data type: `String`

The password of the bind user.

Default value: `$gitlabinstall::ldap_password`

##### `port`

Data type: `Integer`

The port to connect with on your LDAP server. 389 or 636 (for SSL)

Default value: `636`

##### `uid`

Data type: `Enum['userPrincipalName', 'sAMAccountName', 'uid']`

LDAP attribute for username. Should be the attribute, not the value that
maps to the `uid`.

Default value: `'uid'`

##### `user_filter`

Data type: `Optional[String]`

Filter LDAP users. Format: RFC 4515

Default value: ``undef``

##### `full_name`

Data type: `Optional[String]`

LDAP attribute for user display name. If no full name could be found at the
attribute specified for `name`, the full name is determined using the
attributes specified for `first_name` and `last_name`.

Default value: ``undef``

##### `first_name`

Data type: `Optional[String]`

LDAP attribute for user first name.

Default value: ``undef``

##### `last_name`

Data type: `Optional[String]`

LDAP attribute for user last name.

Default value: ``undef``

##### `email`

Data type: `Optional[String]`

LDAP attribute for user email.

Default value: ``undef``

### `gitlabinstall::nginx`

A description of what this class does

#### Examples

##### 

```puppet
include gitlabinstall::nginx
```

#### Parameters

The following parameters are available in the `gitlabinstall::nginx` class.

##### `manage_service`

Data type: `Boolean`

Whether to manage Nginx core settings or not

Default value: `$gitlabinstall::manage_nginx_core`

##### `global_proxy_settings`

Data type: `Boolean`

Whether to enable global proxy cache settings or not. These settings will
reside in Nginx http context (therefore they are global). These settings
could be applied only if Nginx core is managed not here (so `manage_service`
is false)

Default value: ``true``

##### `manage_log_directory`

Data type: `Boolean`

Whether to create own log directory for GitLab or not. This directory
could be managed only if Nginx core is managed not here (so `manage_service`
is false)

Default value: ``true``

##### `monitoring_whitelist`

Data type: `Array[Stdlib::IP::Address]`

GitLab provides liveness and readiness probes to indicate service health.
To access monitoring resources, the requesting client IP needs to be
included in a whitelist.
See https://docs.gitlab.com/ee/administration/monitoring/ip_whitelist.html

Default value: `$gitlabinstall::monitoring_whitelist`

##### `daemon_user`

Data type: `String`



Default value: `$gitlabinstall::params::user`

##### `daemon_user_id`

Data type: `Integer`



Default value: `$gitlabinstall::params::user_id`

##### `daemon_group`

Data type: `String`



Default value: `$gitlabinstall::params::group`

##### `daemon_group_id`

Data type: `Integer`



Default value: `$gitlabinstall::params::group_id`

##### `nginx_user_home`

Data type: `String`



Default value: `$gitlabinstall::params::user_home`

##### `web_server_user_shell`

Data type: `String`



Default value: `$gitlabinstall::params::user_shell`

##### `ssl`

Data type: `Boolean`



Default value: ``false``

##### `ssl_cert_path`

Data type: `Optional[String]`



Default value: ``undef``

##### `ssl_key_path`

Data type: `Optional[String]`



Default value: ``undef``

##### `manage_document_root`

Data type: `Boolean`



Default value: ``false``

### `gitlabinstall::params`

Basic module settings

#### Examples

##### 

```puppet
include gitlabinstall::params
```

### `gitlabinstall::postgres`

Install postgres database and pg_trgm extension

#### Examples

##### 

```puppet
include gitlabinstall::postgres
```

#### Parameters

The following parameters are available in the `gitlabinstall::postgres` class.

##### `database_password`

Data type: `String[8]`



Default value: `$gitlabinstall::database_password`

##### `manage_service`

Data type: `Boolean`



Default value: `$gitlabinstall::manage_postgresql_core`

##### `database_username`

Data type: `String`



Default value: `$gitlabinstall::params::database_username`

##### `database_name`

Data type: `String`



Default value: `$gitlabinstall::params::database_name`

### `gitlabinstall::ssl`

A description of what this class does

#### Examples

##### 

```puppet
include gitlabinstall::ssl
```

#### Parameters

The following parameters are available in the `gitlabinstall::ssl` class.

##### `server_name`

Data type: `Stdlib::Fqdn`

GitLab server name (must be part of external_url)

##### `cert_identity`

Data type: `Optional[String]`

Certificate name to use in order to lookup certificate data in Puppet Hiera
Hiera lookup keys are `<cert_identity>_private` and `<cert_identity>_certificate`
where `<cert_identity>` is normalized value following next rules:

'*' -> 'wildcard', '.' -> '_', '-' -> '_', "'" ->  '_' and ' ' -> '_'

cert_identity must match either certificate Common Name or any of Subject
alternate DNS name

Default value: `$gitlabinstall::cert_identity`

##### `ssl_cert`

Data type: `Optional[String]`

Content of x509 certificate to use for GitLab TLS setup

Default value: ``undef``

##### `ssl_key`

Data type: `Optional[String]`

Content of RSA private key to use for GitLab TLS setup

Default value: ``undef``

##### `manage_cert_data`

Data type: `Boolean`

Whether provided certificate and key should be installed on server
or not

Default value: `$gitlabinstall::manage_cert_data`

## Resource types

### `registry_token`

Registry authentication JWT token

#### Properties

The following properties are available in the `registry_token` type.

##### `access`

Token access levels

Default value: `absent`

##### `audience`

Auth service

Default value: `container_registry`

##### `ensure`

Valid values: `present`, `absent`

Create or remove token.

Default value: `present`

##### `expire_time`

Token expiration time

##### `issued_at`

Time when token have been issued at

##### `issuer`

Token issuer

Default value: `omnibus-gitlab-issuer`

##### `not_before`

Time when token starts to be valid

##### `subject`

Token username

##### `ttl`

Valid values: `%r{^([0-9]+h)?([1-5]?[0-9]m)?([1-5]?[0-9]s)?$}`, `%r{^[0-9]+s?$}`

Controls the expiry of the token

Default value: `24h0m0s`

#### Parameters

The following parameters are available in the `registry_token` type.

##### `id`

Token ID

##### `name`

namevar

Token Name

##### `provider`

The specific backend to use for this `registry_token` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### `target`

Valid values: `%r{^[a-z0-9.-]+$}`

File inside /etc/docker/registry directory where token should be stored

Default value: `token.json`

##### `threshold`

Validity threshold

Default value: `600`

